@@ -13,7 +13,7 @@
 #'        TIGER/Line file).
 #' @param resolution The resolution of the cartographic boundary file (if cb == TRUE).
 #'        Defaults to '500k'; options include '5m' (1:5 million) and '20m' (1:20 million).
-#' @param year the data year (defaults to 2015).
+#' @param year the data year (defaults to 2016).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
 #'        (defaults to \code{FALSE}).
@@ -24,15 +24,15 @@ core_based_statistical_areas <- function(cb = FALSE, resolution = '500k', year =
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2015)
+    year <- getOption("tigris_year", 2016)
 
   }
 
-  if (year < 2011) {
+  if (year < 2010) {
 
     fname <- as.character(match.call())[[1]]
 
-    msg <- sprintf("%s is not currently available for years prior to 2011.  To request this feature,
+    msg <- sprintf("%s is not currently available for years prior to 2010.  To request this feature,
                    file an issue at https://github.com/walkerke/tigris.", fname)
 
     stop(msg, call. = FALSE)
@@ -46,14 +46,28 @@ core_based_statistical_areas <- function(cb = FALSE, resolution = '500k', year =
   cyear <- as.character(year)
 
   if (cb == TRUE) {
-    url <- sprintf("http://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_cbsa_%s.zip",
-                   cyear, cyear, resolution)
+    if (year == 2010) {
+      if (resolution == "5m") stop("Available resolutions are '500k' and '20m'", call. = FALSE)
+      url <- sprintf("https://www2.census.gov/geo/tiger/GENZ2010/gz_2010_us_310_m1_%s.zip",
+                     resolution)
+
+    } else {
+      url <- sprintf("https://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_cbsa_%s.zip",
+                     cyear, cyear, resolution)
+
+      if (year == 2013) url <- gsub("shp/", "", url)
+    }
 
-    if (year == 2013) url <- gsub("shp/", "", url)
 
   } else {
-    url <- sprintf("http://www2.census.gov/geo/tiger/TIGER%s/CBSA/tl_%s_us_cbsa.zip",
-                   cyear, cyear)
+
+    if (year == 2010) {
+      url <- sprintf("https://www2.census.gov/geo/tiger/TIGER2010/CBSA/2010/tl_2010_us_cbsa10.zip")
+    } else {
+      url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/CBSA/tl_%s_us_cbsa.zip",
+                     cyear, cyear)
+    }
+
   }
 
   return(load_tiger(url, tigris_type="cbsa", ...))
@@ -69,7 +83,7 @@ core_based_statistical_areas <- function(cb = FALSE, resolution = '500k', year =
 #' @param cb If cb is set to TRUE, download a generalized (1:500k)
 #'        cartographic boundary file.  Defaults to FALSE (the most detailed
 #'        TIGER/Line file).
-#' @param year the data year (defaults to 2015).
+#' @param year the data year (defaults to 2016).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
 #'        (defaults to \code{FALSE}).
@@ -80,7 +94,7 @@ urban_areas <- function(cb = FALSE, year = NULL, ...) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2015)
+    year <- getOption("tigris_year", 2016)
 
   }
 
@@ -99,13 +113,13 @@ urban_areas <- function(cb = FALSE, year = NULL, ...) {
 
 
   if (cb == TRUE) {
-    url <- sprintf("http://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_ua10_500k.zip",
+    url <- sprintf("https://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_ua10_500k.zip",
                    cyear, cyear)
 
     if (year == 2013) url <- gsub("shp/", "", url)
 
   } else {
-    url <- sprintf("http://www2.census.gov/geo/tiger/TIGER%s/UAC/tl_%s_us_uac10.zip",
+    url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/UAC/tl_%s_us_uac10.zip",
                    cyear, cyear)
   }
 
@@ -124,7 +138,7 @@ urban_areas <- function(cb = FALSE, year = NULL, ...) {
 #'        TIGER/Line file).
 #' @param resolution The resolution of the cartographic boundary file (if cb == TRUE).
 #'        Defaults to '500k'; options include '5m' (1:5 million) and '20m' (1:20 million).
-#' @param year the data year (defaults to 2015).
+#' @param year the data year (defaults to 2016).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
 #'        (defaults to \code{FALSE}).
@@ -135,7 +149,7 @@ combined_statistical_areas <- function(cb = FALSE, resolution = '500k', year = N
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2015)
+    year <- getOption("tigris_year", 2016)
 
   }
 
@@ -157,13 +171,13 @@ combined_statistical_areas <- function(cb = FALSE, resolution = '500k', year = N
   cyear <- as.character(year)
 
   if (cb == TRUE) {
-    url <- sprintf("http://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_csa_%s.zip",
+    url <- sprintf("https://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_csa_%s.zip",
                    cyear, cyear, resolution)
 
     if (year == 2013) url <- gsub("shp/", "", url)
 
   } else {
-    url <- sprintf("http://www2.census.gov/geo/tiger/TIGER%s/CSA/tl_%s_us_csa.zip",
+    url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/CSA/tl_%s_us_csa.zip",
                    cyear, cyear)
   }
 
@@ -176,11 +190,11 @@ combined_statistical_areas <- function(cb = FALSE, resolution = '500k', year = N
 #' Metropolitan divisions are subdivisions of metropolitan areas with population of at least 2.5 million.  Please note:
 #' not all metropolitan areas have metropolitan divisions.
 #'
-#' @param year The data year (defaults to 2015).
+#' @param year The data year (defaults to 2016).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
 #'        (defaults to \code{FALSE}), and \code{year}, the year for which you'd like to download data
-#'        (defaults to 2015).
+#'        (defaults to 2016).
 #' @family metro area functions
 #' @seealso \url{http://www2.census.gov/geo/pdfs/maps-data/data/tiger/tgrshp2015/TGRSHP2015_TechDoc.pdf}
 #' @export
@@ -188,7 +202,7 @@ metro_divisions <- function(year = NULL, ...) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2015)
+    year <- getOption("tigris_year", 2016)
 
   }
 
@@ -205,7 +219,7 @@ metro_divisions <- function(year = NULL, ...) {
 
   cyear <- as.character(year)
 
-  url <- sprintf("http://www2.census.gov/geo/tiger/TIGER%s/METDIV/tl_%s_us_metdiv.zip",
+  url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/METDIV/tl_%s_us_metdiv.zip",
                  cyear, cyear)
 
   return(load_tiger(url, tigris_type="metro", ...))
@@ -230,11 +244,11 @@ metro_divisions <- function(year = NULL, ...) {
 #' @param cb If cb is set to TRUE, download a generalized (1:500k)
 #'        cartographic boundary file.  Defaults to FALSE (the most detailed
 #'        TIGER/Line file).  Only available when \code{type = 'necta'}.
-#' @param year The data year (defaults to 2015).
+#' @param year The data year (defaults to 2016).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
 #'        (defaults to \code{FALSE}), and \code{year}, the year for which you'd like to download data
-#'        (defaults to 2015).
+#'        (defaults to 2016).
 #' @family metro area functions
 #' @seealso \url{http://www2.census.gov/geo/pdfs/maps-data/data/tiger/tgrshp2015/TGRSHP2015_TechDoc.pdf}
 #' @export
@@ -251,7 +265,7 @@ new_england <- function(type = 'necta', cb = FALSE, year = NULL, ...) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2015)
+    year <- getOption("tigris_year", 2016)
 
   }
 
@@ -272,12 +286,12 @@ new_england <- function(type = 'necta', cb = FALSE, year = NULL, ...) {
 
     if (cb == TRUE) {
 
-      url <- sprintf("http://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_necta_500k.zip",
+      url <- sprintf("https://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_necta_500k.zip",
                      cyear, cyear)
 
     } else {
 
-      url <- sprintf("http://www2.census.gov/geo/tiger/TIGER%s/NECTA/tl_%s_us_necta.zip",
+      url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/NECTA/tl_%s_us_necta.zip",
                      cyear, cyear)
 
     }
@@ -286,14 +300,14 @@ new_england <- function(type = 'necta', cb = FALSE, year = NULL, ...) {
 
   } else if (type == 'combined') {
 
-    url <- sprintf("http://www2.census.gov/geo/tiger/TIGER%s/CNECTA/tl_%s_us_cnecta.zip",
+    url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/CNECTA/tl_%s_us_cnecta.zip",
                    cyear, cyear)
 
     return(load_tiger(url, tigris_type = "cnecta", ...))
 
   } else if (type == 'divisions') {
 
-    url <- sprintf("http://www2.census.gov/geo/tiger/TIGER%s/NECTADIV/tl_%s_us_nectadiv.zip",
+    url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/NECTADIV/tl_%s_us_nectadiv.zip",
                    cyear, cyear)
 
     return(load_tiger(url, tigris_type = "nectadiv", ...))
