@@ -31,13 +31,15 @@ fips_state_table <- structure(list(abb = c("ak", "al", "ar", "as", "az", "ca", "
 
 
 .onLoad <- function(libname, pkgname) {
-  options(tigris_refresh=FALSE)
-  options(tigris_use_cache=FALSE)
-  options(tigris_year = 2015)
-  options(tigris_class = "sp")
+  # options(tigris_refresh=FALSE)
+  # options(tigris_use_cache=FALSE)
+  # options(tigris_year = 2015)
+  # options(tigris_class = "sp")
   data("fips_codes", package=pkgname, envir=parent.env(environment()))
 }
 
 .onAttach <- function(libname, pkgname) {
-  packageStartupMessage("As of version 0.5.1, tigris does not cache downloaded data by default. To enable caching of data, set `options(tigris_use_cache = TRUE)` in your R script or .Rprofile.")
+  packageStartupMessage("To enable \ncaching of data, set `options(tigris_use_cache = TRUE)` in your R script or .Rprofile.")
 }
+
+utils::globalVariables(c(".data", "geoid"))
